==> baseui-5.4.0.tgz: package/es/tooltip/__tests__/styled-components.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _index = require("../index.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
describe('Tooltip styled components', function () {
  test('StyledBody - basic render', function () {
    var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledBody, {
      $isOpen: false,
      $isAnimating: false,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 0
      },
      $popoverOffset: {
        top: 0,
        left: 0
      },
      $showArrow: true
    }, _react.default.createElement("div", null)));
    expect(component.instance().getStyles()).toMatchSnapshot('StyledBody has correct styles when closed');
    component.setProps({
      $isOpen: true,
      $isAnimating: true,
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      }
    });
    expect(component.instance().getStyles()).toMatchSnapshot('StyledBody has correct styles when open and animating');
  });
  test('StyledInner - basic render', function () {
    var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledInner, {
      $isOpen: true,
      $isAnimating: true,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      },
      $showArrow: true
    }, _react.default.createElement("div", null)));
    expect(component.instance().getStyles()).toMatchSnapshot('StyledInner has correct styles');
  });
  test('StyledInner - override', function () {
    var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledInner, {
      $isOpen: true,
      $isAnimating: true,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      },
      $showArrow: true,
      $style: {
        background: 'aliceblue'
      }
    }, _react.default.createElement("div", null)));
    expect(component.instance().getStyles()).toHaveProperty('background', 'aliceblue');
  });
  test('StyledArrow - basic render', function () {
    var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledArrow, {
      $isOpen: true,
      $isAnimating: true,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      },
      $showArrow: true
    }, _react.default.createElement("div", null)));
    expect(component.instance().getStyles()).toMatchSnapshot('StyledArrow has correct styles');
  });
});

==> baseui-5.12.1.tgz: package/es/tooltip/__tests__/styled-components.test.js <==
/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import React from 'react';
import { shallow } from 'enzyme';
import { StyledBody, StyledInner, StyledArrow } from '../index.js';
describe('Tooltip styled components', function () {
  test('StyledBody - basic render', function () {
    var component = shallow(React.createElement(StyledBody, {
      $isOpen: false,
      $isAnimating: false,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 0
      },
      $popoverOffset: {
        top: 0,
        left: 0
      },
      $showArrow: true
    }, React.createElement("div", null)));
    expect(component.instance().getStyles()).toMatchSnapshot('StyledBody has correct styles when closed');
    component.setProps({
      $isOpen: true,
      $isAnimating: true,
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      }
    });
    expect(component.instance().getStyles()).toMatchSnapshot('StyledBody has correct styles when open and animating');
  });
  test('StyledInner - basic render', function () {
    var component = shallow(React.createElement(StyledInner, {
      $isOpen: true,
      $isAnimating: true,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      },
      $showArrow: true
    }, React.createElement("div", null)));
    expect(component.instance().getStyles()).toMatchSnapshot('StyledInner has correct styles');
  });
  test('StyledInner - override', function () {
    var component = shallow(React.createElement(StyledInner, {
      $isOpen: true,
      $isAnimating: true,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      },
      $showArrow: true,
      $style: {
        background: 'aliceblue'
      }
    }, React.createElement("div", null)));
    expect(component.instance().getStyles()).toHaveProperty('background', 'aliceblue');
  });
  test('StyledArrow - basic render', function () {
    var component = shallow(React.createElement(StyledArrow, {
      $isOpen: true,
      $isAnimating: true,
      $placement: "bottomLeft",
      $arrowOffset: {
        top: 0,
        left: 10
      },
      $popoverOffset: {
        top: 100,
        left: 100
      },
      $showArrow: true
    }, React.createElement("div", null)));
    expect(component.instance().getStyles()).toMatchSnapshot('StyledArrow has correct styles');
  });
});
